exceptiontools.ClefError
========================

.. abjad-lineage:: abjad.tools.exceptiontools.ClefError.ClefError

.. autoclass:: abjad.tools.exceptiontools.ClefError.ClefError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ClefError.ClefError.__unicode__
   :noindex:
